==> rjx-2.0.2.tgz: package/rollup.config.js <==
// import path from 'path';
import resolve from 'rollup-plugin-node-resolve';
import commonjs from 'rollup-plugin-commonjs';
import babel from 'rollup-plugin-babel';
import builtins from 'rollup-plugin-node-builtins';
import globals from 'rollup-plugin-node-globals';
import replace from 'rollup-plugin-replace';
// import alias from 'rollup-plugin-alias';
import pkg from './package.json';
// import { terser, } from 'rollup-plugin-terser';
import terser from 'rollup-plugin-terser-js';

export default [
  // browser-friendly UMD build
  {
    input: 'src/main.js',
    // external: [ 'react' ], // <-- suppresses the warning
    output:[{
      exports: 'named',
      file: pkg.browser,
      format: 'umd',
      name: 'rjx',
    }, {
      exports: 'named',
      file: pkg.web,
      format: 'iife',
      name: 'rjx',
    },
    ],
    plugins: [
      replace({
        'process.env.NODE_ENV': JSON.stringify( 'development' ),
        // 'process.env.NODE_ENV': JSON.stringify( 'production' ),
      }),
      resolve({
        preferBuiltins: true,
      }), // so Rollup can find `ms`
      builtins({
      }),
      babel({
        runtimeHelpers: true,
        // 'presets': [
        //   ['@babel/env', { },],
        // ],
        plugins: [
          [
            '@babel/transform-runtime',
            // { useESModules: output.format !== 'cjs' }
          ],
        ],
        // exclude: 'node_modules/**', // only transpile our source code
      }),
      commonjs({
        namedExports: {
          // left-hand side can be an absolute path, a path
          // relative to the current directory, or the name
          // of a module in node_modules
          // 'node_modules/ml-array-utils/src/index.js': [ 'scale' ]
          'node_modules/react/index.js': ['Children', 'Component', 'PropTypes','Fragment', 'createElement', 'useState', 'useEffect', 'useContext', 'useReducer', 'useCallback', 'useMemo', 'useRef', 'useImperativeHandle', 'useLayoutEffect', 'useDebugValue',],

        },
      }), // so Rollup can convert `ms` to an ES module
      globals({
      }),
      terser({
        sourcemap: true
      }),
    ],
  },

  // CommonJS (for Node) and ES module (for bundlers) build.
  // (We could have three entries in the configuration array
  // instead of two, but it's quicker to generate multiple
  // builds from a single configuration where possible, using
  // an array for the `output` option, where we can specify 
  // `file` and `format` for each target)
  {
    input: 'src/main.js',
    external: [
      'react',
      'react-dom',
      'react-dom/server',
      'react-dom-factories',
      'create-react-class',
      'ua-parser-js',
    ], // <-- suppresses the warning
    output: [
      {
        name: 'rjx',
        exports: 'named',
        file: pkg.main,
        format: 'cjs',
      },
      {
        name: 'rjx',
        exports: 'named',
        file: pkg.module,
        format: 'es',
      },
    ],
    plugins: [
      babel({
        // exclude: 'node_modules/**', // only transpile our source code
        runtimeHelpers: true,
        // 'presets': [
        //   // ['@babel/env', { },],
        //   '@babel/env'
        // ],
        plugins: [
          [
            '@babel/transform-runtime',
            // { useESModules: output.format !== 'cjs' }
          ],
        ],
        // exclude: 'node_modules/**', // only transpile our source code
      }),
    ],
    watch: {
      include: 'src/**',
    },
  },
  // CommonJS (for Node) and ES module (for bundlers) build.
  // (We could have three entries in the configuration array
  // instead of two, but it's quicker to generate multiple
  // builds from a single configuration where possible, using
  // an array for the `output` option, where we can specify 
  // `file` and `format` for each target)
  {
    input: 'src/main.js',
    external: [
      'react',
      'react-dom',
      'react-dom/server',
      'react-dom-factories',
      'create-react-class',
      'ua-parser-js',
    ], // <-- suppresses the warning
    output: [
      {
        name: 'rjx',
        exports: 'named',
        file: 'dist/rjx-server.cjs.js',
        format: 'cjs',
      },
      {
        name: 'rjx',
        exports: 'named',
        file: 'dist/rjx-server.esm.js',
        format: 'es',
      },
    ],
    plugins: [
      // aliasModuleSpecifiers({
      //   'react-dom/': 'react-dom/server/',
      // }),
      // alias({
      //   'react-dom': path.resolve('./node_modules/react-dom/server.node.js'),
      //   ReactDOM: path.resolve('./node_modules/react-dom/server.node.js'),
      // }),
      babel({
        // exclude: 'node_modules/**', // only transpile our source code
        runtimeHelpers: true,
        // 'presets': [
        //   // ['@babel/env', { },],
        //   '@babel/env'
        // ],
        plugins: [
          [
            '@babel/transform-runtime',
            // { useESModules: output.format !== 'cjs' }
          ],
          ['babel-plugin-replace-imports', {
            'test': /react-dom$/,
            'replacer': 'react-dom/server',
          }, ],
        ],
        // exclude: 'node_modules/**', // only transpile our source code
      }),
    ],
    watch: {
      include: 'src/**',
    },
  },
  // BROWSER MIN
  {
    input: 'src/main.js',
    // external: [ 'react' ], // <-- suppresses the warning
    output:[{
      exports: 'named',
      file: 'dist/rjx.umd.min.js',
      format: 'umd',
      name: 'rjx',
    }, {
      exports: 'named',
      file: 'dist/rjx.web.min.js',
      format: 'iife',
      name: 'rjx',
    },
    ],
    plugins: [
      replace({
        // 'process.env.NODE_ENV': JSON.stringify( 'development' ),
        'process.env.NODE_ENV': JSON.stringify( 'production' ),
      }),
      resolve({
        preferBuiltins: true,
      }), // so Rollup can find `ms`
      builtins({
      }),
      babel({
        runtimeHelpers: true,
        plugins: [
          [
            '@babel/transform-runtime',
          ],
          ['babel-plugin-replace-imports', {
            'test': /react-dom\/server/,
            'replacer': '../test/mock/_mock_react-dom-server',
          }, ],
          // ['babel-plugin-replace-imports', {
          //   'test': /react$/,
          //   'replacer': 'react/cjs/react.production.min.js',
          // },'r-rename' ],
          ['babel-plugin-replace-imports', {
            'test': /ua-parser-js$/,
            'replacer': '../test/mock/_mock_react-dom-server',
          },'u-rename' ],
        ],
        // exclude: 'node_modules/**', // only transpile our source code
      }),
      commonjs({
        namedExports: {
          // left-hand side can be an absolute path, a path
          // relative to the current directory, or the name
          // of a module in node_modules
          // 'node_modules/ml-array-utils/src/index.js': [ 'scale' ]
          'node_modules/react/index.js':[
          // 'node_modules/react/cjs/react.production.min.js': [
            'Children', 'Component', 'PropTypes', 'Fragment', 'createElement', 'useState', 'useEffect', 'useContext', 'useReducer', 'useCallback', 'useMemo', 'useRef', 'useImperativeHandle', 'useLayoutEffect', 'useDebugValue',
          ],

        },
      }), // so Rollup can convert `ms` to an ES module
      globals({
      }),
      terser({
        sourcemaps:true,
        compress: true,
        mangle: true,
      }),
    ],
  },
];

==> rjx-2.1.0.tgz: package/rollup.config.js <==
// import path from 'path';
import resolve from 'rollup-plugin-node-resolve';
import commonjs from 'rollup-plugin-commonjs';
import babel from 'rollup-plugin-babel';
import builtins from 'rollup-plugin-node-builtins';
import globals from 'rollup-plugin-node-globals';
import replace from 'rollup-plugin-replace';
// import alias from 'rollup-plugin-alias';
import pkg from './package.json';
// import { terser, } from 'rollup-plugin-terser';
import terser from 'rollup-plugin-terser-js';

export default [
  // browser-friendly UMD build
  {
    input: 'src/main.js',
    // external: [ 'react' ], // <-- suppresses the warning
    output:[{
      exports: 'named',
      file: pkg.browser,
      format: 'umd',
      name: 'rjx',
    }, {
      exports: 'named',
      file: pkg.web,
      format: 'iife',
      name: 'rjx',
    },
    ],
    plugins: [
      replace({
        'process.env.NODE_ENV': JSON.stringify( 'development' ),
        // 'process.env.NODE_ENV': JSON.stringify( 'production' ),
      }),
      resolve({
        preferBuiltins: true,
      }), // so Rollup can find `ms`
      builtins({
      }),
      babel({
        runtimeHelpers: true,
        // 'presets': [
        //   ['@babel/env', { },],
        // ],
        plugins: [
          [
            '@babel/transform-runtime',
            // { useESModules: output.format !== 'cjs' }
          ],
        ],
        // exclude: 'node_modules/**', // only transpile our source code
      }),
      commonjs({
        namedExports: {
          // left-hand side can be an absolute path, a path
          // relative to the current directory, or the name
          // of a module in node_modules
          // 'node_modules/ml-array-utils/src/index.js': [ 'scale' ]
          'node_modules/react/index.js': ['Children', 'Component', 'PropTypes','Fragment', 'createElement', 'useState', 'useEffect', 'useContext', 'useReducer', 'useCallback', 'useMemo', 'useRef', 'useImperativeHandle', 'useLayoutEffect', 'useDebugValue',],

        },
      }), // so Rollup can convert `ms` to an ES module
      globals({
      }),
      terser({
        sourcemap: true
      }),
    ],
  },

  // CommonJS (for Node) and ES module (for bundlers) build.
  // (We could have three entries in the configuration array
  // instead of two, but it's quicker to generate multiple
  // builds from a single configuration where possible, using
  // an array for the `output` option, where we can specify 
  // `file` and `format` for each target)
  {
    input: 'src/main.js',
    external: [
      'react',
      'react-dom',
      'react-dom/server',
      'react-dom-factories',
      'create-react-class',
      'ua-parser-js',
    ], // <-- suppresses the warning
    output: [
      {
        name: 'rjx',
        exports: 'named',
        file: pkg.main,
        format: 'cjs',
      },
      {
        name: 'rjx',
        exports: 'named',
        file: pkg.module,
        format: 'es',
      },
    ],
    plugins: [
      babel({
        // exclude: 'node_modules/**', // only transpile our source code
        runtimeHelpers: true,
        // 'presets': [
        //   // ['@babel/env', { },],
        //   '@babel/env'
        // ],
        plugins: [
          [
            '@babel/transform-runtime',
            // { useESModules: output.format !== 'cjs' }
          ],
        ],
        // exclude: 'node_modules/**', // only transpile our source code
      }),
    ],
    watch: {
      include: 'src/**',
    },
  },
  // CommonJS (for Node) and ES module (for bundlers) build.
  // (We could have three entries in the configuration array
  // instead of two, but it's quicker to generate multiple
  // builds from a single configuration where possible, using
  // an array for the `output` option, where we can specify 
  // `file` and `format` for each target)
  {
    input: 'src/main.js',
    external: [
      'react',
      'react-dom',
      'react-dom/server',
      'react-dom-factories',
      'create-react-class',
      'ua-parser-js',
    ], // <-- suppresses the warning
    output: [
      {
        name: 'rjx',
        exports: 'named',
        file: 'dist/rjx-server.cjs.js',
        format: 'cjs',
      },
      {
        name: 'rjx',
        exports: 'named',
        file: 'dist/rjx-server.esm.js',
        format: 'es',
      },
    ],
    plugins: [
      // aliasModuleSpecifiers({
      //   'react-dom/': 'react-dom/server/',
      // }),
      // alias({
      //   'react-dom': path.resolve('./node_modules/react-dom/server.node.js'),
      //   ReactDOM: path.resolve('./node_modules/react-dom/server.node.js'),
      // }),
      babel({
        // exclude: 'node_modules/**', // only transpile our source code
        runtimeHelpers: true,
        // 'presets': [
        //   // ['@babel/env', { },],
        //   '@babel/env'
        // ],
        plugins: [
          [
            '@babel/transform-runtime',
            // { useESModules: output.format !== 'cjs' }
          ],
          ['babel-plugin-replace-imports', {
            'test': /react-dom$/,
            'replacer': 'react-dom/server',
          }, ],
        ],
        // exclude: 'node_modules/**', // only transpile our source code
      }),
    ],
    watch: {
      include: 'src/**',
    },
  },
  // BROWSER MIN
  {
    input: 'src/main.js',
    // external: [ 'react' ], // <-- suppresses the warning
    output:[{
      exports: 'named',
      file: 'dist/rjx.umd.min.js',
      format: 'umd',
      name: 'rjx',
    }, {
      exports: 'named',
      file: 'dist/rjx.web.min.js',
      format: 'iife',
      name: 'rjx',
    },
    ],
    plugins: [
      replace({
        // 'process.env.NODE_ENV': JSON.stringify( 'development' ),
        'process.env.NODE_ENV': JSON.stringify( 'production' ),
      }),
      resolve({
        preferBuiltins: true,
      }), // so Rollup can find `ms`
      builtins({
      }),
      babel({
        runtimeHelpers: true,
        plugins: [
          [
            '@babel/transform-runtime',
          ],
          ['babel-plugin-replace-imports', {
            'test': /react-dom\/server/,
            'replacer': '../design/_mock_react-dom-server',
          }, ],
          // ['babel-plugin-replace-imports', {
          //   'test': /react$/,
          //   'replacer': 'react/cjs/react.production.min.js',
          // },'r-rename' ],
          ['babel-plugin-replace-imports', {
            'test': /ua-parser-js$/,
            'replacer': '../design/_mock_react-dom-server',
          },'u-rename' ],
        ],
        // exclude: 'node_modules/**', // only transpile our source code
      }),
      commonjs({
        namedExports: {
          // left-hand side can be an absolute path, a path
          // relative to the current directory, or the name
          // of a module in node_modules
          // 'node_modules/ml-array-utils/src/index.js': [ 'scale' ]
          'node_modules/react/index.js':[
          // 'node_modules/react/cjs/react.production.min.js': [
            'Children', 'Component', 'PropTypes', 'Fragment', 'createElement', 'useState', 'useEffect', 'useContext', 'useReducer', 'useCallback', 'useMemo', 'useRef', 'useImperativeHandle', 'useLayoutEffect', 'useDebugValue',
          ],

        },
      }), // so Rollup can convert `ms` to an ES module
      globals({
      }),
      terser({
        sourcemaps:true,
        compress: true,
        mangle: true,
      }),
    ],
  },
];
